@@ -2,7 +2,7 @@
 /**
  * ggv-control.c
  *
- * Authors:  Jaka Mocnik  <jaka@gnu.org>
+ * Author:  Jaka Mocnik  <jaka@gnu.org>
  *
  * Copyright (c) 2001, 2002 Free Software Foundation
  */
@@ -37,14 +37,9 @@ struct _GgvControlPrivate {
 };
 
 struct _GgvControlClassPrivate {
-#ifdef DYNAMIC_ZOOM_MENUS
-	BonoboUINode *zoom_level_menus;
-#else
 	int dummy;
-#endif /* DYNAMIC_ZOOM_MENUS */
 };
 
-#ifndef DYNAMIC_ZOOM_MENUS
 static struct {
 	gfloat level;
 	gchar *path;
@@ -56,7 +51,6 @@ static struct {
 	{ 4.0/1.0, "/commands/Zoom0401" },
 	{ 0.0, NULL }
 };
-#endif /* !DYNAMIC_ZOOM_MENUS */
 
 static BonoboControlClass *ggv_control_parent_class;
 
@@ -67,7 +61,7 @@ ggv_control_prefs_changed(GConfClient *client, guint cnxn_id,
 	GgvControl *control = GGV_CONTROL(user_data);
 
 	if(!strcmp(entry->key, "/apps/ggv/control/autojump"))
-		control->priv->pane_auto_jump = gconf_value_get_bool(entry->value);
+	   control->priv->pane_auto_jump = gconf_value_get_bool(entry->value);
 }
 
 static void
@@ -514,9 +508,6 @@ extern BonoboUIVerb ggv_postscript_view_verbs[];
 static void
 ggv_control_create_ui (GgvControl *control)
 {
-#ifdef DYNAMIC_ZOOM_MENUS
-	BonoboUINode *zoom_level_menus;
-#endif /* DYNAMIC_ZOOM_MENUS */
 	GgvControlClass *klass;
 	int i;
 
@@ -531,19 +522,11 @@ ggv_control_create_ui (GgvControl *control)
 	bonobo_ui_util_set_ui(control->priv->popup_uic, NULL, "ggv-postscript-view-ui.xml", "GGV", NULL);
 	bonobo_ui_util_set_ui(control->priv->popup_uic, NULL, "ggv-control-ui.xml", "GGV", NULL);
 	
-#ifdef DYNAMIC_ZOOM_MENUS
-	zoom_level_menus = bonobo_ui_node_copy(klass->priv->zoom_level_menus,
-										   TRUE);
-	bonobo_ui_component_set_tree(control->priv->uic,
-								 "/menu/ViewPlaceholder/View/ZoomMenu/Zoom/ZoomLevels",
-								 zoom_level_menus, NULL);
-#else
 	for(i = 0; zoom_level_items[i].path; i++) {
 		bonobo_ui_component_add_listener(control->priv->uic,
 										 zoom_level_items[i].path + strlen("/commands/"),
 										 listener_ZoomLevel_cb, control);
 	}
-#endif /* DYNAMIC_ZOOM_MENUS */
 
 	set_zoom_items_sensitivity(control, ggv_postscript_view_get_page_count(control->priv->ps_view) > 0);
 
@@ -575,7 +558,9 @@ ggv_control_set_ui_container (GgvControl *control,
 
 	bonobo_ui_component_set_container (control->priv->uic, ui_container, NULL);
 
-	if(!control->priv->has_zoomable_frame) {
+	/* NOTE: we always merge our UI, as we have more than merely zoom items
+	   to offer. */
+	if(TRUE || !control->priv->has_zoomable_frame) {
 		ggv_control_create_ui(control);
 	}
 }
@@ -633,21 +618,6 @@ ggv_control_class_init (GgvControlClass *klass)
 	control_class->activate = ggv_control_activate;
 
 	klass->priv = g_new0(GgvControlClassPrivate, 1);
-
-#ifdef DYNAMIC_ZOOM_MENUS
-	placeholder = bonobo_ui_node_new("placeholder");
-	bonobo_ui_node_set_attr(placeholder, "name", "ZoomLevels");
-	for(i = 0; i <= ggv_max_zoom_levels; i++) {
-		item = bonobo_ui_node_new("menuitem");
-		bonobo_ui_node_set_attr(item, "name", ggv_zoom_level_names[i]);
-		bonobo_ui_node_set_attr(item, "label", ggv_zoom_level_names[i]);
-		bonobo_ui_node_set_attr(item, "type", "radio");
-		bonobo_ui_node_set_attr(item, "group", "ZoomLevel");
-		bonobo_ui_node_set_attr(item, "verb", "");		
-		bonobo_ui_node_add_child(placeholder, item);
-	}
-	klass->priv->zoom_level_menus = placeholder;
-#endif /* DYNAMIC_ZOOM_MENUS */
 }
 
 static void
