@@ -24,11 +24,12 @@
 #include <gsdefaults.h>
 #include <ggvutils.h>
 #include <ggv-msg-window.h>
+#include <ggv-prefs.h>
+#include <ggv-prefs-ui.h>
+#include <ggv-sidebar.h>
 
 #include <bonobo.h>
 
-#undef DYNAMIC_PAPER_MENUS
-
 struct _GgvPostScriptViewPrivate {
 	GtkWidget *gs;
 	GtkObject *hadj, *vadj;
@@ -42,6 +43,9 @@ struct _GgvPostScriptViewPrivate {
 	gchar *tmp_name;
 
 	GgvMsgWindow *msg_win;
+	GgvSidebar *sidebar;
+
+	GtkWidget *save_file_sel;
 
 	BonoboPropertyBag     *property_bag;
 	BonoboPropertyControl *property_control;
@@ -52,12 +56,7 @@ struct _GgvPostScriptViewPrivate {
 };
 
 struct _GgvPostScriptViewClassPrivate {
-#ifdef DYNAMIC_PAPER_MENUS
-	BonoboUINode   *size_menus;
-	gchar          **size_paths;
-#else
 	int dummy;
-#endif /* DYNAMIC_PAPER_MENUS */
 };
 
 enum {
@@ -95,7 +94,6 @@ static const gchar *orientation_paths[] = {
 	NULL
 };
 
-#ifndef DYNAMIC_PAPER_MENUS
 static const gchar *size_paths[] = {
 	"/commands/OverrideSize",
 	"/commands/PaperSizeBBox",
@@ -115,7 +113,6 @@ static const gchar *size_paths[] = {
 	"/commands/PaperSize10x14",
 	NULL
 };
-#endif /* DYNAMIC_PAPER_MENUS */
 
 void
 get_status(GgvPostScriptView *ps_view, BonoboArg *arg)
@@ -130,6 +127,14 @@ get_status(GgvPostScriptView *ps_view, BonoboArg *arg)
 	*(CORBA_string *)arg->_value = CORBA_string_dup(status);
 }
 
+static void
+prefs_changed_handler(gpointer data)
+{
+	GgvPostScriptView *ps_view = GGV_POSTSCRIPT_VIEW(data);
+
+	/* TODO: set sidebar properties - coordinate units */
+}
+
 static void
 get_title(GgvPostScriptView *ps_view, BonoboArg *arg)
 {
@@ -262,10 +267,12 @@ static void
 load_ps(GgvPostScriptView *ps_view, const gchar *fname)
 {
 	gtk_gs_load(GTK_GS(ps_view->priv->gs), fname);
+	ggv_sidebar_create_page_list(ps_view->priv->sidebar);
 	notify_title_change(ps_view);
 	notify_page_count_change(ps_view);
 	notify_orientation_change(ps_view);
 	ggv_postscript_view_goto_page(ps_view, 0);
+	ggv_sidebar_update_coordinates(ps_view->priv->sidebar, 0.0, 0.0);
 }
 
 /*
@@ -403,7 +410,6 @@ view_motion_cb(GtkWidget *widget, GdkEventMotion *event, gpointer data)
 	g_return_if_fail(GGV_IS_POSTSCRIPT_VIEW(data));
 
 	ps_view = GGV_POSTSCRIPT_VIEW(data);
-
 	if(ps_view->priv->pan) {
 		gtk_gs_scroll(GTK_GS(ps_view->priv->gs),
 					  -(gint)event->x + ps_view->priv->prev_x,
@@ -413,6 +419,19 @@ view_motion_cb(GtkWidget *widget, GdkEventMotion *event, gpointer data)
 
 		return TRUE;
 	}
+	else {
+		GtkGS *gs;
+
+		gs = GTK_GS(ps_view->priv->gs);
+		if(event->window == gs->pstarget && gs->doc != NULL) {
+			gfloat xcoord, ycoord;
+		
+			xcoord = event->x/gs->xdpi/gs->zoom_factor;
+			ycoord = event->y/gs->ydpi/gs->zoom_factor;
+			
+			ggv_sidebar_update_coordinates(ps_view->priv->sidebar, xcoord, ycoord);
+		}
+	}
 
 	return FALSE;
 }
@@ -569,6 +588,210 @@ listener_Size_cb(BonoboUIComponent *uic, const char *path,
 	bonobo_arg_release(arg);
 }
 
+
+static gchar *
+ggv_postscript_view_get_ps(GgvPostScriptView *ps_view, gint *active_rows)
+{
+	gchar *ps;
+
+	if(active_rows == NULL)
+		ps = gtk_gs_get_postscript(GTK_GS(ps_view->priv->gs), NULL);
+	else {
+		gint num, i;
+		GtkGS *gs;
+		gint *page_mask;
+
+		gs = GTK_GS(ps_view->priv->gs);
+		num = gtk_gs_get_page_count(gs);
+		page_mask = g_new0(gint, num);
+
+		for(i = 0; active_rows[i] != -1; i++) {
+			if(active_rows[i] < num)
+				page_mask[active_rows[i]] = TRUE;
+		}
+		ps = gtk_gs_get_postscript(gs, page_mask);
+	}
+	return ps;
+}
+
+static void
+ggv_postscript_view_print(GgvPostScriptView *ps_view, gchar *ps)
+{
+	gchar **argv;
+	gint print_in;
+
+	argv = g_strsplit(ggv_print_cmd, " ", 0);
+	if(!g_spawn_async_with_pipes(NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
+								 NULL, NULL, NULL, &print_in, NULL, NULL,
+								 NULL)) {
+		GtkWidget *dlg;
+		dlg = gtk_message_dialog_new(GTK_WINDOW(gtk_widget_get_toplevel(ps_view->priv->gs)),
+									 GTK_DIALOG_MODAL,
+									 GTK_MESSAGE_ERROR,
+									 GTK_BUTTONS_OK,
+									 _("Unable to execute print command:\n%s"),
+									 ggv_print_cmd);
+		gtk_widget_show(dlg);
+		gtk_dialog_run(GTK_DIALOG(dlg));
+		gtk_widget_destroy(dlg);
+	}
+	else {
+		write(print_in, ps, strlen(ps));
+		close(print_in);
+	}
+	g_strfreev(argv);
+}
+
+static void
+save_file_sel_unmap(GtkWidget *widget)
+{
+	ggv_get_window_size(widget, &file_sel_width, &file_sel_height);
+}
+
+static gboolean
+save_file_sel_delete_event(GtkWidget *widget, GdkEventAny *e, gpointer data)
+{
+	gtk_widget_hide(widget);
+	return FALSE;
+}
+
+static void
+save_file_sel_ok_clicked(GtkWidget *widget, gpointer data)
+{
+	GgvPostScriptView *ps_view = GGV_POSTSCRIPT_VIEW(data);
+	gint *active_rows;
+	const gchar *fname;
+	gchar *doc;
+	FILE *f;
+
+	active_rows = ggv_sidebar_get_active_list(ps_view->priv->sidebar);
+	doc = ggv_postscript_view_get_ps(ps_view, active_rows);
+	g_free(active_rows);
+
+	if(doc != NULL) {
+		/* get file name */
+		gtk_widget_hide(ps_view->priv->save_file_sel);
+		fname = gtk_file_selection_get_filename(GTK_FILE_SELECTION(ps_view->priv->save_file_sel));
+		
+		if(fname && (f = fopen(fname, "w")) != NULL) {
+			fwrite(doc, 1, strlen(doc), f);
+			fclose(f);
+		}
+		g_free(doc);
+	}
+}
+
+static void
+save_file_sel_cancel_clicked(GtkWidget *widget, gpointer data)
+{
+	GgvPostScriptView *ps_view = GGV_POSTSCRIPT_VIEW(data);
+
+	gtk_widget_hide(ps_view->priv->save_file_sel);
+}
+
+static void
+verb_FileSaveMarked(BonoboUIComponent *uic, gpointer data, const char *cname)
+{
+	GgvPostScriptView *ps_view = GGV_POSTSCRIPT_VIEW(data);
+	gint *active_rows;
+	
+	active_rows = ggv_sidebar_get_active_list(ps_view->priv->sidebar);
+	if(active_rows[0] == -1) {
+		GtkWidget *dlg;
+		
+		dlg = gtk_message_dialog_new(GTK_WINDOW(gtk_widget_get_toplevel(ps_view->priv->gs)),
+									 GTK_DIALOG_MODAL,
+									 GTK_MESSAGE_QUESTION,
+									 GTK_BUTTONS_YES_NO,
+									 _("No pages have been marked.\n"
+									   "Do you want to save the whole document?"));
+		gtk_widget_show(dlg);
+		switch(gtk_dialog_run(GTK_DIALOG(dlg))) {
+		case GTK_RESPONSE_NO:
+		case GTK_RESPONSE_DELETE_EVENT:
+			gtk_widget_destroy(dlg);
+			return;
+		default:
+			break;
+		}
+		gtk_widget_destroy(dlg);
+	}
+	g_free(active_rows);
+	
+	if(!ps_view->priv->save_file_sel) {
+		gchar *home_path = g_strconcat(g_get_home_dir(), "/", NULL);
+		ps_view->priv->save_file_sel = gtk_file_selection_new(_("Select a file to save pages as"));
+		gtk_file_selection_set_filename(GTK_FILE_SELECTION(ps_view->priv->save_file_sel),
+										home_path);
+		g_free(home_path);
+		gtk_window_set_transient_for(GTK_WINDOW(ps_view->priv->save_file_sel),
+									 GTK_WINDOW(gtk_widget_get_toplevel(ps_view->priv->gs)));
+		gtk_file_selection_hide_fileop_buttons(GTK_FILE_SELECTION(ps_view->priv->save_file_sel));
+		gtk_window_set_resizable(GTK_WINDOW(ps_view->priv->save_file_sel), TRUE);
+		g_signal_connect(G_OBJECT(GTK_FILE_SELECTION(ps_view->priv->save_file_sel)->ok_button),
+						 "clicked", G_CALLBACK(save_file_sel_ok_clicked), ps_view);
+		g_signal_connect(G_OBJECT(GTK_FILE_SELECTION(ps_view->priv->save_file_sel)->cancel_button),
+						 "clicked", G_CALLBACK(save_file_sel_cancel_clicked), ps_view);
+		g_signal_connect(G_OBJECT(ps_view->priv->save_file_sel), "delete_event",
+						 G_CALLBACK(save_file_sel_delete_event), ps_view);
+		g_signal_connect(G_OBJECT(ps_view->priv->save_file_sel), "unmap",
+						 G_CALLBACK(save_file_sel_unmap), NULL);
+	}
+	if(!GTK_WIDGET_VISIBLE(ps_view->priv->save_file_sel)) {
+		gtk_widget_set_usize(GTK_WIDGET(ps_view->priv->save_file_sel),
+							 file_sel_width, file_sel_height);
+		gtk_widget_show(ps_view->priv->save_file_sel);
+		ggv_raise_and_focus_widget(ps_view->priv->save_file_sel);
+	}
+}
+
+static void
+verb_FilePrintMarked(BonoboUIComponent *uic, gpointer data, const char *cname)
+{
+	GgvPostScriptView *ps_view = GGV_POSTSCRIPT_VIEW(data);
+	gchar *ps;
+	gint *active_rows;
+	
+	active_rows = ggv_sidebar_get_active_list(ps_view->priv->sidebar);
+	if(active_rows[0] == -1) {
+		GtkWidget *dlg;
+		
+		dlg = gtk_message_dialog_new(GTK_WINDOW(gtk_widget_get_toplevel(ps_view->priv->gs)),
+									 GTK_DIALOG_MODAL,
+									 GTK_MESSAGE_QUESTION,
+									 GTK_BUTTONS_YES_NO,
+									 _("No pages have been marked.\n"
+									   "Do you want to print the whole document?"));
+		gtk_widget_show(dlg);
+		switch(gtk_dialog_run(GTK_DIALOG(dlg))) {
+		case GTK_RESPONSE_NO:
+		case GTK_RESPONSE_DELETE_EVENT:
+			gtk_widget_destroy(dlg);
+			return;
+		default:
+			break;
+		}
+		gtk_widget_destroy(dlg);
+	}
+	if((ps = ggv_postscript_view_get_ps(ps_view, active_rows)) != NULL) {
+		ggv_postscript_view_print(ps_view, ps);
+		g_free(ps);
+	}
+	g_free(active_rows);
+}
+
+static void
+verb_FilePrintAll(BonoboUIComponent *uic, gpointer data, const char *cname)
+{
+	GgvPostScriptView *ps_view = GGV_POSTSCRIPT_VIEW(data);
+	gchar *ps;
+
+	if((ps = ggv_postscript_view_get_ps(ps_view, NULL)) != NULL) {
+		ggv_postscript_view_print(ps_view, ps);
+		g_free(ps);
+	}
+}
+
 static void
 verb_NextPage_cb(BonoboUIComponent *uic, gpointer user_data, const char *cname)
 {
@@ -629,6 +852,18 @@ verb_FirstPage_cb(BonoboUIComponent *uic, gpointer user_data, const char *cname)
 	ggv_postscript_view_goto_page(ps_view, 0);
 }
 
+static void
+verb_SettingsPreferences(BonoboUIComponent *uic, gpointer data, const char *cname)
+{
+        static GtkWidget *dlg = NULL;
+
+        if(dlg == NULL) {
+                dlg = ggv_prefs_dialog_new();
+        }
+        ggv_prefs_dialog_show(GGV_PREFS_DIALOG(dlg));
+		ggv_raise_and_focus_widget(dlg);
+}
+
 static void
 sync_orientation_items(GgvPostScriptView *ps_view)
 {
@@ -654,11 +889,7 @@ sync_size_items(GgvPostScriptView *ps_view)
 	gboolean val, size_state;
 	const gchar **paths;
 
-#if DYNAMIC_PAPER_MENUS
-	paths = GGV_POSTSCRIPT_VIEW_CLASS(G_OBJECT_GET_CLASS(ps_view))->priv->size_paths;
-#else
 	paths = size_paths;
-#endif /* DYNAMIC_PAPER_MENUS */
 
 	val = gtk_gs_get_override_size(GTK_GS(ps_view->priv->gs));
 	bonobo_ui_component_set_prop(ps_view->priv->uic, paths[0],
@@ -673,19 +904,20 @@ sync_size_items(GgvPostScriptView *ps_view)
 }
 
 BonoboUIVerb ggv_postscript_view_verbs[] = {
-	BONOBO_UI_VERB ("NextPage", verb_NextPage_cb),
-	BONOBO_UI_VERB ("PrevPage", verb_PrevPage_cb),
-	BONOBO_UI_VERB ("LastPage", verb_LastPage_cb),
-	BONOBO_UI_VERB ("FirstPage", verb_FirstPage_cb),
+	BONOBO_UI_VERB("SettingsPreferences", verb_SettingsPreferences),
+	BONOBO_UI_VERB("FileSaveMarked", verb_FileSaveMarked),
+	BONOBO_UI_VERB("FilePrintMarked", verb_FilePrintMarked),
+	BONOBO_UI_VERB("FilePrintAll", verb_FilePrintAll),
+	BONOBO_UI_VERB("NextPage", verb_NextPage_cb),
+	BONOBO_UI_VERB("PrevPage", verb_PrevPage_cb),
+	BONOBO_UI_VERB("LastPage", verb_LastPage_cb),
+	BONOBO_UI_VERB("FirstPage", verb_FirstPage_cb),
 	BONOBO_UI_VERB_END
 };
 
 static void
 ggv_postscript_view_create_ui(GgvPostScriptView *ps_view)
 {
-#ifdef DYNAMIC_PAPER_MENUS
-	BonoboUINode *new_size_menus;
-#endif /* DYNAMIC_PAPER_MENUS */
 	BonoboUINode *ui_root;
 	GgvPostScriptViewClass *klass = GGV_POSTSCRIPT_VIEW_CLASS(G_OBJECT_GET_CLASS(ps_view));
 	gint i;
@@ -697,28 +929,18 @@ ggv_postscript_view_create_ui(GgvPostScriptView *ps_view)
 	bonobo_ui_util_set_ui(ps_view->priv->uic, DATADIR,
 						  "ggv-postscript-view-ui.xml", 
 						  "GGV", NULL);
+	bonobo_ui_component_object_set(ps_view->priv->uic, "/Sidebar/GgvSidebar",
+								   BONOBO_OBJREF(ps_view->priv->sidebar), NULL);
+	bonobo_ui_component_set_prop(ps_view->priv->uic, "/Sidebar",
+								 "hidden", ggv_panel?"0":"1", NULL);
 	bonobo_ui_component_add_verb_list_with_data(ps_view->priv->uic,
 												ggv_postscript_view_verbs,
 												ps_view);
 
-#ifdef DYNAMIC_PAPER_MENUS
-	new_size_menus = bonobo_ui_node_copy(klass->priv->size_menus, TRUE);
-
-	if(new_size_menus) {
-		bonobo_ui_component_set_tree(ps_view->priv->uic, "/menu/ViewPlaceholder/View/Size/SizeList",
-									 new_size_menus, NULL);
-	}
-
-	for(i = 1; klass->priv->size_paths[i]; i++) 
-		bonobo_ui_component_add_listener(ps_view->priv->uic,
-										 klass->priv->size_paths[i] + strlen("/commands/"),
-										 listener_Size_cb, ps_view);
-#else
 	for(i = 1; size_paths[i]; i++) 
 		bonobo_ui_component_add_listener(ps_view->priv->uic,
 										 size_paths[i] + strlen("/commands/"),
 										 listener_Size_cb, ps_view);
-#endif /* DYNAMIC_PAPER_MENUS */
 
 	for(i = 1; orientation_paths[i]; i++) 
 		bonobo_ui_component_add_listener(ps_view->priv->uic,
@@ -734,6 +956,23 @@ ggv_postscript_view_create_ui(GgvPostScriptView *ps_view)
 	sync_size_items(ps_view);
 }
 
+gchar **
+ggv_postscript_view_get_page_names(GgvPostScriptView *ps_view)
+{
+	gchar **names = NULL;
+	GtkGS *gs;
+	gint i;
+
+	gs = GTK_GS(ps_view->priv->gs);
+	if(gs->loaded && gs->doc && gs->structured_doc) {
+		names = g_new0(gchar *, gs->doc->numpages + 1);
+		for(i = 0; i < gs->doc->numpages; i++) {
+			names[i] = g_strdup(gs->doc->pages[i].label);
+		}
+	}
+	return names;
+}
+
 static void
 ggv_postscript_view_get_prop(BonoboPropertyBag *bag,
 							 BonoboArg         *arg,
@@ -1293,6 +1532,8 @@ ggv_postscript_view_destroy(BonoboObject *object)
 		ps_view->priv->uic = NULL;
 	}
 
+	ggv_prefs_remove_callback(ps_view);
+
 	if (BONOBO_OBJECT_CLASS (ggv_postscript_view_parent_class)->destroy)
 		BONOBO_OBJECT_CLASS(ggv_postscript_view_parent_class)->destroy(object);
 }
@@ -1369,33 +1610,6 @@ ggv_postscript_view_class_init(GgvPostScriptViewClass *klass)
 
 	ggv_postscript_view_parent_class = g_type_class_peek_parent(klass);
 
-#ifdef DYNAMIC_PAPER_MENUS
-	/* FIXME: can't get these dynamically created menus to merge
-	   properly. for the time being we have made them static in the
-	   UI XML files */
-	/* init size menu template */
-	placeholder = bonobo_ui_node_new("placeholder");
-	bonobo_ui_node_set_attr(placeholder, "name", "SizeList");
-	papersizes = gtk_gs_defaults_get_paper_sizes();
-	klass->priv->size_paths = g_new0(gchar *, n + 2);
-	for(i = 0; i < n; i++) {
-		item = bonobo_ui_node_new("menuitem");
-		klass->priv->size_paths[i + 1] =
-			g_strdup_printf("/commands/%s", papersizes[i].name);
-		bonobo_ui_node_set_attr(item, "name", papersizes[i].name);
-		enc_str = bonobo_ui_util_encode_str(_(papersizes[i].name));
-		bonobo_ui_node_set_attr(item, "label", enc_str);
-		g_free(enc_str);
-		bonobo_ui_node_set_attr(item, "type", "radio");
-		bonobo_ui_node_set_attr(item, "group", "Size");
-		bonobo_ui_node_set_attr(item, "verb", "");
-		bonobo_ui_node_add_child(placeholder, item);
-	}
-	klass->priv->size_paths[0] = "/commands/OverrideSize";
-	klass->priv->size_paths[n + 1] = NULL;
-	klass->priv->size_menus = placeholder;
-#endif /* DYNAMIC_PAPER_MENUS  */
-
 	bonobo_object_class->destroy = ggv_postscript_view_destroy;
 	object_class->finalize = ggv_postscript_view_finalize;
 	
@@ -1403,6 +1617,9 @@ ggv_postscript_view_class_init(GgvPostScriptViewClass *klass)
 
 	epv->getDocument = impl_GNOME_GGV_PostScriptView_getDocument;
 	epv->getPages = impl_GNOME_GGV_PostScriptView_getPages;
+
+	/* this seems as a nice place to load the prefs */
+	ggv_prefs_load();
 }
 
 static void
@@ -1604,6 +1821,10 @@ ggv_postscript_view_construct(GgvPostScriptView *ps_view,
 
 	ggv_postscript_view_add_interfaces (ps_view, BONOBO_OBJECT (ps_view));
 
+	ps_view->priv->sidebar = ggv_sidebar_new(ps_view);
+
+	ggv_prefs_add_callback(prefs_changed_handler, ps_view);
+
 	return ps_view;
 }
 
