@@ -124,84 +124,6 @@ sync_toolbar_style(GgvWindow *win)
         bonobo_ui_component_set_prop(win->uic, "/Toolbar", "look",
                                      ggv_toolbar_labels?"both":"icon", NULL);
 }
-        
-static CORBA_string
-ggv_window_get_ps_from_control(GgvWindow *win, gint *active_rows)
-{
-        GNOME_GGV_PostScriptView ggv;
-        CORBA_Environment ev;
-        CORBA_string doc;
-        GNOME_GGV_PageList *page_list;
-        FILE *f;
-        CORBA_long page_count;
-        gint i;
-
-        CORBA_exception_init(&ev);
-
-        /* get reference of our PostScriptView interface */
-        ggv = Bonobo_Unknown_queryInterface(win->control,
-                                            "IDL:GNOME/GGV/PostScriptView:1.0", &ev);
-        if(BONOBO_EX(&ev) || ggv == CORBA_OBJECT_NIL) {
-                CORBA_exception_free(&ev);
-                return CORBA_OBJECT_NIL;
-        }
-
-        /* TODO: check if the doc is structured */
-
-        /* allocate space for page list */
-        page_count = bonobo_pbclient_get_long(win->pb, "page_count", NULL);
-        page_list = CORBA_sequence_CORBA_long__alloc();
-        page_list->_maximum = page_count;
-        page_list->_length = 0;
-        page_list->_buffer = CORBA_sequence_CORBA_long_allocbuf(page_count);
-        page_list->_release = TRUE;
-        /* and fill it in if necessary */
-        if(active_rows) {
-                i = 0;
-                while(active_rows[i] >= 0) {
-                        page_list->_buffer[page_list->_length++] = active_rows[i++];
-                }
-        }
-
-        if(page_list->_length == 0)
-                doc = GNOME_GGV_PostScriptView_getDocument(ggv, &ev);
-        else
-                doc = GNOME_GGV_PostScriptView_getPages(ggv, page_list, &ev);
-
-        CORBA_free(page_list);
-
-        CORBA_exception_free(&ev);
-
-        return doc;
-}
-
-static void
-ggv_window_print_postscript(GgvWindow *win, CORBA_string ps)
-{
-        gchar **argv;
-        gint print_in;
-
-        argv = g_strsplit(ggv_print_cmd, " ", 0);
-        if(!g_spawn_async_with_pipes(NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
-                                     NULL, NULL, NULL, &print_in, NULL, NULL,
-                                     NULL)) {
-                GtkWidget *dlg;
-                dlg = gtk_message_dialog_new(GTK_WINDOW(win),
-                                             GTK_DIALOG_MODAL,
-                                             GTK_MESSAGE_ERROR,
-                                             GTK_BUTTONS_OK,
-                                             _("Unable to execute print command:\n%s"),
-                                             ggv_print_cmd);
-                gtk_widget_show(dlg);
-                gtk_dialog_run(GTK_DIALOG(dlg));
-                gtk_widget_destroy(dlg);
-        }
-        else {
-                write(print_in, ps, strlen(ps));
-                close(print_in);
-        }
-        g_strfreev(argv);
-}
 
 static void
 set_file_items_sensitivity(GgvWindow *win, gboolean sens)
@@ -257,30 +179,15 @@ control_property_changed_handler(BonoboListener    *listener,
                         gtk_widget_destroy(dlg);
                         return;
                 }
-
-                sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(win->checklist));
-                g_snprintf(path_str, 15, "%d", BONOBO_ARG_GET_INT(any));
-                path = gtk_tree_path_new_from_string(path_str);
-                if(!gtk_tree_selection_path_is_selected(sel, path))
-                        gtk_tree_selection_select_path(sel, path);
-                gtk_tree_path_free(path);
         }
         else if(!g_strcasecmp(event_name, "Bonobo/Property:change:page_count")) {
         }
 }
 
-static void
-get_window_size(GtkWidget *widget, gint *width, gint *height)
-{
-        *width = widget->allocation.width;
-        *height = widget->allocation.height;
-}
-
-
 static void
 file_sel_unmap(GtkWidget *widget)
 {
-        get_window_size(widget, &file_sel_width, &file_sel_height);
+        ggv_get_window_size(widget, &file_sel_width, &file_sel_height);
 }
 
 static gboolean
@@ -320,40 +227,6 @@ file_sel_cancel_clicked(GtkWidget *widget, gpointer data)
         gtk_widget_hide(win->file_sel);
 }
 
-static void
-save_file_sel_ok_clicked(GtkWidget *widget, gpointer data)
-{
-        GgvWindow *win = GGV_WINDOW(data);
-        gint *active_rows;
-        const gchar *fname;
-        CORBA_string doc;
-        FILE *f;
-
-        active_rows = gtk_check_list_get_active_list(GTK_CHECK_LIST(win->checklist));
-        doc = ggv_window_get_ps_from_control(win, active_rows);
-        g_free(active_rows);
-
-        if(doc != CORBA_OBJECT_NIL) {
-                /* get file name */
-                gtk_widget_hide(win->save_file_sel);
-                fname = gtk_file_selection_get_filename(GTK_FILE_SELECTION(win->save_file_sel));
-
-                if(fname && (f = fopen(fname, "w")) != NULL) {
-                        fwrite(doc, 1, strlen(doc), f);
-                        fclose(f);
-                }
-                CORBA_free(doc);
-        }
-}
-
-static void
-save_file_sel_cancel_clicked(GtkWidget *widget, gpointer data)
-{
-        GgvWindow *win = GGV_WINDOW(data);
-
-        gtk_widget_hide(win->save_file_sel);
-}
-
 static void
 verb_FileOpen(BonoboUIComponent *uic, gpointer data, const char *cname)
 {
@@ -361,6 +234,7 @@ verb_FileOpen(BonoboUIComponent *uic, gpointer data, const char *cname)
 
         if(!win->file_sel) {
                 win->file_sel = gtk_file_selection_new(_("Select a PostScript document"));
+                gtk_window_set_transient_for(GTK_WINDOW(win->file_sel), GTK_WINDOW(win));
                 gtk_file_selection_hide_fileop_buttons(GTK_FILE_SELECTION(win->file_sel));
                 gtk_window_set_resizable(GTK_WINDOW(win->file_sel), TRUE);
                 g_signal_connect(G_OBJECT(GTK_FILE_SELECTION(win->file_sel)->ok_button),
@@ -387,104 +261,6 @@ verb_FileClose(BonoboUIComponent *uic, gpointer data, const char *cname)
         ggv_window_close(win);
 }
 
-static void
-verb_FileSaveMarked(BonoboUIComponent *uic, gpointer data, const char *cname)
-{
-        GgvWindow *win = GGV_WINDOW(data);
-        gint *active_rows;
-
-        active_rows = gtk_check_list_get_active_list(GTK_CHECK_LIST(win->checklist));
-        if(!active_rows) {
-                GtkWidget *dlg;
-
-                dlg = gtk_message_dialog_new(GTK_WINDOW(win),
-                                             GTK_DIALOG_MODAL,
-                                             GTK_MESSAGE_QUESTION,
-                                             GTK_BUTTONS_YES_NO,
-                                             _("No pages have been marked.\n"
-                                               "Do you want to save the whole document?"));
-                gtk_widget_show(dlg);
-                switch(gtk_dialog_run(GTK_DIALOG(dlg))) {
-                case GTK_RESPONSE_NO:
-                case GTK_RESPONSE_DELETE_EVENT:
-                        return;
-                default:
-                        break;
-                }
-                gtk_widget_destroy(dlg);
-        }
-        else
-                g_free(active_rows);
-        
-
-        if(!win->save_file_sel) {
-                win->save_file_sel = gtk_file_selection_new(_("Select a file to save pages as"));
-                gtk_file_selection_hide_fileop_buttons(GTK_FILE_SELECTION(win->save_file_sel));
-                gtk_window_set_resizable(GTK_WINDOW(win->save_file_sel), TRUE);
-                g_signal_connect(G_OBJECT(GTK_FILE_SELECTION(win->save_file_sel)->ok_button),
-                                 "clicked", G_CALLBACK(save_file_sel_ok_clicked), win);
-                g_signal_connect(G_OBJECT(GTK_FILE_SELECTION(win->save_file_sel)->cancel_button),
-                                 "clicked", G_CALLBACK(save_file_sel_cancel_clicked), win);
-                g_signal_connect(G_OBJECT(win->save_file_sel), "delete_event",
-                                 G_CALLBACK(file_sel_cancel_clicked), win);
-                g_signal_connect(G_OBJECT(win->save_file_sel), "unmap",
-                                 G_CALLBACK(file_sel_unmap), NULL);
-        }
-        if(!GTK_WIDGET_VISIBLE(win->save_file_sel)) {
-                gtk_widget_set_usize(GTK_WIDGET(win->save_file_sel),
-                                     file_sel_width, file_sel_height);
-                gtk_widget_show(win->save_file_sel);
-        }
-}
-
-static void
-verb_FilePrintMarked(BonoboUIComponent *uic, gpointer data, const char *cname)
-{
-        GgvWindow *win = GGV_WINDOW(data);
-        CORBA_string ps;
-        gint *active_rows;
-
-        active_rows = gtk_check_list_get_active_list(GTK_CHECK_LIST(win->checklist));
-        if(!active_rows) {
-                GtkWidget *dlg;
-
-                dlg = gtk_message_dialog_new(GTK_WINDOW(win),
-                                             GTK_DIALOG_MODAL,
-                                             GTK_MESSAGE_QUESTION,
-                                             GTK_BUTTONS_YES_NO,
-                                             _("No pages have been marked.\n"
-                                               "Do you want to print the whole document?"));
-                gtk_widget_show(dlg);
-                switch(gtk_dialog_run(GTK_DIALOG(dlg))) {
-                case GTK_RESPONSE_NO:
-                case GTK_RESPONSE_DELETE_EVENT:
-                        return;
-                default:
-                        break;
-                }
-                gtk_widget_destroy(dlg);
-        }
-        if((ps = ggv_window_get_ps_from_control(win, active_rows)) != CORBA_OBJECT_NIL) {
-                ggv_window_print_postscript(win, ps);
-                CORBA_free(ps);
-        }
-        if(active_rows)
-                g_free(active_rows);
-}
-
-static void
-verb_FilePrintAll(BonoboUIComponent *uic, gpointer data, const char *cname)
-{
-        GgvWindow *win = GGV_WINDOW(data);
-
-        CORBA_string ps;
-
-        if((ps = ggv_window_get_ps_from_control(win, NULL)) != CORBA_OBJECT_NIL) {
-                ggv_window_print_postscript(win, ps);
-                CORBA_free(ps);
-        }
-}
-
 static void
 verb_FileNew(BonoboUIComponent *uic, gpointer data, const char *cname)
 {
@@ -504,17 +280,6 @@ verb_FileExit(BonoboUIComponent *uic, gpointer data, const char *cname)
         bonobo_main_quit();
 }
 
-static void
-verb_SettingsPreferences(BonoboUIComponent *uic, gpointer data, const char *cname)
-{
-        static GtkWidget *dlg = NULL;
-
-        if(dlg == NULL) {
-                dlg = ggv_prefs_dialog_new();
-        }
-        ggv_prefs_dialog_show(GGV_PREFS_DIALOG(dlg));
-}
-
 static void
 listener_SettingsShow (BonoboUIComponent *uic, const char *path,
                        Bonobo_UIComponent_EventType type, const char *state,
@@ -545,10 +310,8 @@ listener_SettingsShow (BonoboUIComponent *uic, const char *path,
 	else if(!strcmp(path, "SettingsShowSidebar")) {
                 if(window->show_sidebar != state_f) {
                         window->show_sidebar = state_f;
-                        if(state_f)
-                                gtk_widget_show(window->sidebar);
-                        else
-                                gtk_widget_hide(window->sidebar);
+                        bonobo_ui_component_set_prop(window->uic, "/Sidebar", "hidden",
+                                                     state_f?"0":"1", NULL);
                 }
         }
 	else if(!strcmp(path, "SettingsShowToolbar")) {
@@ -607,6 +370,8 @@ verb_HelpAbout(BonoboUIComponent *uic, gpointer data, const char *cname)
 			NULL, /* char **documentors */
 			NULL, /* char *translators */
 			logo);
+                gtk_window_set_transient_for(GTK_WINDOW(about),
+                                             GTK_WINDOW(data));
 		g_signal_connect (G_OBJECT (about), "destroy",
                                   G_CALLBACK (gtk_widget_destroyed),
                                   &about);
@@ -673,11 +438,7 @@ static BonoboUIVerb ggv_app_verbs[] = {
         BONOBO_UI_VERB("FileNew", verb_FileNew),
         BONOBO_UI_VERB("FileClose", verb_FileClose),
         BONOBO_UI_VERB("FileOpen", verb_FileOpen),
-        BONOBO_UI_VERB("FileSaveMarked", verb_FileSaveMarked),
-        BONOBO_UI_VERB("FilePrintMarked", verb_FilePrintMarked),
-        BONOBO_UI_VERB("FilePrintAll", verb_FilePrintAll),
         BONOBO_UI_VERB("FileExit", verb_FileExit),
-        BONOBO_UI_VERB("SettingsPreferences", verb_SettingsPreferences),
         BONOBO_UI_VERB("HelpAbout", verb_HelpAbout),
         BONOBO_UI_VERB("DnDNewWindow", verb_DnDNewWindow),
         BONOBO_UI_VERB("DnDThisWindow", verb_DnDThisWindow),
@@ -701,132 +462,6 @@ control_frame_activate_uri(BonoboControlFrame *control_frame, const char *uri,
         }
 }
 
-static gboolean
-cl_toggle_all(GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer data)
-{
-        gboolean val;
-
-        gtk_tree_model_get(model, iter, 0, &val, -1);
-        gtk_list_store_set(GTK_LIST_STORE(model), iter, 0, !val, -1);
-
-        return FALSE;
-}
-
-static gboolean
-cl_toggle_even(GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer data)
-{
-        gint *n = (gint *)data;
-        if(*n%2 == 0) {
-                gboolean val;
-                gtk_tree_model_get(model, iter, 0, &val, -1);
-                gtk_list_store_set(GTK_LIST_STORE(model), iter, 0, !val, -1);
-        }
-        (*n)++;
-        return FALSE;
-}
-
-static gboolean
-cl_toggle_odd(GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer data)
-{
-        gint *n = (gint *)data;
-        if(*n%2 != 0) {
-                gboolean val;
-                gtk_tree_model_get(model, iter, 0, &val, -1);
-                gtk_list_store_set(GTK_LIST_STORE(model), iter, 0, !val, -1);
-        }
-        (*n)++;
-        return FALSE;
-}
-
-static gboolean
-cl_clear_all(GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer data)
-{
-        gtk_list_store_set(GTK_LIST_STORE(model), iter, 0, FALSE, -1);
-        return FALSE;
-}
-
-static void
-toggle_all_clicked(GtkWidget *widget, gpointer data)
-{
-        GgvWindow *win = GGV_WINDOW(data);
-        gtk_tree_model_foreach(GTK_TREE_MODEL(GTK_CHECK_LIST(win->checklist)->list_model),
-                               cl_toggle_all, NULL);
-}
-
-static void
-toggle_odd_clicked(GtkWidget *widget, gpointer data)
-{
-        gint n = 1;
-        GgvWindow *win = GGV_WINDOW(data);
-        gtk_tree_model_foreach(GTK_TREE_MODEL(GTK_CHECK_LIST(win->checklist)->list_model),
-                               cl_toggle_odd, &n);
-}
-
-static void
-toggle_even_clicked(GtkWidget *widget, gpointer data)
-{
-        GgvWindow *win = GGV_WINDOW(data);
-        gint n = 1;
-        gtk_tree_model_foreach(GTK_TREE_MODEL(GTK_CHECK_LIST(win->checklist)->list_model),
-                               cl_toggle_even, &n);
-}
-
-static void
-clear_all_clicked(GtkWidget *widget, gpointer data)
-{
-        GgvWindow *win = GGV_WINDOW(data);
-        gtk_tree_model_foreach(GTK_TREE_MODEL(GTK_CHECK_LIST(win->checklist)->list_model),
-                               cl_clear_all, NULL);
-}
-
-static void
-page_list_selection_changed(GtkTreeSelection *sel,
-                            gpointer user_data)
-{
-        GgvWindow *win = GGV_WINDOW(user_data);
-        GtkTreeIter iter;
-        GtkTreeModel *model;
-
-        if(gtk_tree_selection_get_selected(sel, &model, &iter)) {
-                GtkTreePath *path;
-                gint page;
-                gchar *path_str;
-
-                path = gtk_tree_model_get_path(model,
-                                               &iter);
-                path_str = gtk_tree_path_to_string(path);
-                page = atoi(path_str);
-                g_free(path_str);
-                if(page >= 0)
-                        bonobo_pbclient_set_long(win->pb, "page", page, NULL);
-        }
-}
-
-static void
-ggv_window_create_page_list(GgvWindow *win)
-{
-        CORBA_long page_count;
-        GNOME_GGV_PageNameList *page_names;
-        BonoboArg *arg;
-        int i;
-
-        page_count = bonobo_pbclient_get_long(win->pb, "page_count", NULL);
-        arg = bonobo_pbclient_get_value(win->pb, "page_names",
-                                        TC_GNOME_GGV_PageNameList,
-                                        NULL);
-        if(arg == NULL) {
-                g_warning("Unable to fetch page names from control.");
-                return;
-        }
-        page_names = (GNOME_GGV_PageNameList *)arg->_value;
-        for(i = 0; i < page_names->_length; i++) {
-                gtk_check_list_append_row(GTK_CHECK_LIST(win->checklist),
-                                          page_names->_buffer[i]);                                                  
-        }
-        CORBA_sequence_set_release(page_names, CORBA_TRUE);
-        bonobo_arg_release(arg);
-}
-
 static void
 ggv_window_destroy(GtkObject *object)
 {
@@ -842,7 +477,7 @@ ggv_window_destroy(GtkObject *object)
                 win->ctlframe = NULL;
         }
 
-        get_window_size(GTK_WIDGET(object),
+        ggv_get_window_size(GTK_WIDGET(object),
                         &ggv_default_width, &ggv_default_height);
 
         if(GTK_OBJECT_CLASS(parent_class)->destroy)
@@ -957,69 +592,6 @@ ggv_window_new(void)
         gtk_box_pack_start(GTK_BOX(win->vbox), win->hbox,
                            TRUE, TRUE, 2);
 
-
-        /* with a sidebar on the left */
-        win->sidebar = gtk_vbox_new(FALSE, 0);
-        if(ggv_panel)
-                gtk_widget_show(win->sidebar);
-        gtk_box_pack_start(GTK_BOX(win->hbox), win->sidebar,
-                           FALSE, TRUE, 0);
-
-        hbox = gtk_hbox_new(TRUE, 2);
-        gtk_widget_show(hbox);
-        gtk_box_pack_start(GTK_BOX(win->sidebar), hbox, FALSE, TRUE, 0);
-
-        image = gtk_image_new_from_file(GNOMEICONDIR "/ggv/toggleall.xpm");
-        gtk_widget_show(image);
-        win->toggle_all = gtk_button_new();
-        gtk_button_set_relief(GTK_BUTTON(win->toggle_all), GTK_RELIEF_NONE);
-        gtk_widget_show(win->toggle_all);
-        gtk_box_pack_start(GTK_BOX(hbox), win->toggle_all, FALSE, TRUE, 0);
-        gtk_container_add(GTK_CONTAINER(win->toggle_all), image);
-        g_signal_connect(G_OBJECT(win->toggle_all), "clicked",
-                         G_CALLBACK(toggle_all_clicked), win);
-        image = gtk_image_new_from_file(GNOMEICONDIR "/ggv/toggleodd.xpm");
-        gtk_widget_show(image);
-        win->toggle_odd = gtk_button_new();
-        gtk_button_set_relief(GTK_BUTTON(win->toggle_odd), GTK_RELIEF_NONE);
-        gtk_widget_show(win->toggle_odd);
-        gtk_box_pack_start(GTK_BOX(hbox), win->toggle_odd, FALSE, TRUE, 0);
-        gtk_container_add(GTK_CONTAINER(win->toggle_odd), image);
-        g_signal_connect(G_OBJECT(win->toggle_odd), "clicked",
-                         G_CALLBACK(toggle_odd_clicked), win);
-        image = gtk_image_new_from_file(GNOMEICONDIR "/ggv/toggleeven.xpm");
-        gtk_widget_show(image);
-        win->toggle_even = gtk_button_new();
-        gtk_button_set_relief(GTK_BUTTON(win->toggle_even), GTK_RELIEF_NONE);
-        gtk_widget_show(win->toggle_even);
-        gtk_box_pack_start(GTK_BOX(hbox), win->toggle_even, FALSE, TRUE, 0);
-        gtk_container_add(GTK_CONTAINER(win->toggle_even), image);
-        g_signal_connect(G_OBJECT(win->toggle_even), "clicked",
-                         G_CALLBACK(toggle_even_clicked), win);
-        image = gtk_image_new_from_file(GNOMEICONDIR "/ggv/clearall.xpm");
-        gtk_widget_show(image);
-        win->clear_all = gtk_button_new();
-        gtk_button_set_relief(GTK_BUTTON(win->clear_all), GTK_RELIEF_NONE);
-        gtk_widget_show(win->clear_all);
-        gtk_box_pack_start(GTK_BOX(hbox), win->clear_all, FALSE, TRUE, 0);
-        gtk_container_add(GTK_CONTAINER(win->clear_all), image);
-        g_signal_connect(G_OBJECT(win->clear_all), "clicked",
-                         G_CALLBACK(clear_all_clicked), win);
-
-        /* a checklist */
-        win->checklist = gtk_check_list_new();
-        sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(win->checklist));
-        g_signal_connect(G_OBJECT(sel), "changed",
-                         G_CALLBACK(page_list_selection_changed), win);
-        gtk_widget_show(win->checklist);
-
-        sw = gtk_scrolled_window_new(NULL, NULL);
-        gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(sw),
-                                            GTK_SHADOW_IN);
-        gtk_widget_show(sw);
-        gtk_container_add(GTK_CONTAINER(sw), win->checklist);
-        gtk_box_pack_start(GTK_BOX(win->sidebar), sw, TRUE, TRUE, 0);
-        
 	/* add statusbar */
 	win->statusbar = gnome_appbar_new(FALSE, TRUE,
                                           GNOME_PREFERENCES_NEVER);
@@ -1118,7 +690,11 @@ ggv_window_new(void)
 	/* set default geometry */
         gtk_widget_set_usize(GTK_WIDGET(win),
                              ggv_default_width, ggv_default_height);
+#if 0
 	gtk_window_set_resizable(GTK_WINDOW(win), TRUE);
+#else
+        gtk_window_set_policy(GTK_WINDOW(win), TRUE, TRUE, FALSE);
+#endif
 
 	return GTK_WIDGET(win);
 }
@@ -1172,10 +748,6 @@ ggv_window_load(GgvWindow *win, const gchar *filename)
         }
         CORBA_exception_free(&ev);
 
-        gtk_check_list_clear(GTK_CHECK_LIST(win->checklist));
-
-        ggv_window_create_page_list(win);
-
         return TRUE;
 }
 
