@@ -48,10 +48,7 @@ struct _GgvWindow
         BonoboUIComponent *uic, *popup_uic;
 
         GtkWidget *hbox, *vbox;
-        GtkWidget *sidebar, *statusbar;
-        GtkWidget *checklist;
-        GtkWidget *toggle_all, *toggle_even, *toggle_odd, *clear_all;
-        GtkWidget *coordinates;
+        GtkWidget *statusbar;
         GtkWidget *popup_menu;
         GtkWidget *file_sel;
         GtkWidget *save_file_sel;
